summaryrefslogtreecommitdiff
path: root/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/sama5d3x-ek/src/sam_buttons.c')
-rw-r--r--nuttx/configs/sama5d3x-ek/src/sam_buttons.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/nuttx/configs/sama5d3x-ek/src/sam_buttons.c b/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
index 4377a2f5d..fe74f3fb7 100644
--- a/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
+++ b/nuttx/configs/sama5d3x-ek/src/sam_buttons.c
@@ -56,6 +56,7 @@
#include <stdint.h>
+#include <nuttx/arch.h>
#include <nuttx/irq.h>
#include <arch/irq.h>
@@ -87,17 +88,17 @@ static xcpt_t g_irquser1;
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
(void)sam_configpio(PIO_USER1);
}
@@ -106,7 +107,7 @@ void up_buttoninit(void)
* Name: up_buttons
*
* Description:
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON* definitions
* above for the meaning of each bit in the returned value.
@@ -87,17 +88,17 @@ static xcpt_t g_irquser1;
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -106,7 +107,7 @@ void up_buttoninit(void)
*
* Description:
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON* definitions